@@ -1,19 +1,18 @@
-'''
+"""
 An opionated set of helpers for defining Docker integration test environments with py.test fixtures.
-'''
+"""
 
 from .factories import build, container, fetch, image, image_or_build, network, volume
 
-
-__version__ = '0.2.2'
+__version__ = "0.2.3"
 
 
 __all__ = [
-    'build',
-    'container',
-    'fetch',
-    'image',
-    'image_or_build',
-    'network',
-    'volume',
+    "build",
+    "container",
+    "fetch",
+    "image",
+    "image_or_build",
+    "network",
+    "volume",
 ]
