@@ -32,7 +32,7 @@ def pytest_runtest_makereport(item, call):
         return
 
     for name, fixturedef in item.funcargs["request"]._fixture_defs.items():
-        if not hasattr(fixturedef, "cached_result"):
+        if not hasattr(fixturedef, "cached_result") or not fixturedef.cached_result:
             continue
         fixture = fixturedef.cached_result[0]
         if isinstance(fixture, Container):
@@ -42,3 +42,14 @@ def pytest_runtest_makereport(item, call):
                     fixture.logs(),
                 )
             )
+
+
+def pytest_addoption(parser):
+    group = parser.getgroup("pytest-docker-tools", "Pytest Docker Tools")
+    group.addoption(
+        "--reuse-containers",
+        action="store_true",
+        dest="reuse_containers",
+        help="reuse existing containers instead of always creating new ones. Requires the 'name' attribute to be set"
+        "on container definition",
+    )
